%global mod_name kafka
%global project_name %{mod_name}-python

Summary:          Pure Python client for Apache Kafka
Name:             python-%{mod_name}
Version:          2.0.2
Release:          6%{?dist}
License:          ASL 2.0
URL:              https://github.com/dpkp/%{project_name}
Source0:          %{url}/archive/refs/tags/%{version}.tar.gz
Source1:          LICENSE_doc

Patch3000:        test_conn.py.patch
Patch3001:        test_default_records.py.patch
Patch3002:        test_legacy_records.py.patch
Patch3003:        setup.py.patch
Patch3004:        test_assignors.py.patch

Patch5000:        fix_test_assert_error.patch

BuildRequires: pyproject-rpm-macros python3-devel python3-pip python3-wheel
BuildRequires: python3-pytest python3-pytest-mock python3-snappy python3-lz4 python3-zstandard python3-xxhash
# for doc
BuildRequires: python3-sphinx_rtd_theme make
BuildArch:        noarch


%description
This module provides low-level protocol support for Apache Kafka as well as high-level consumer and
producer classes. Request batching is supported by the protocol as well as broker-aware request
routing. Gzip and Snappy compression is also supported for message sets.

%package -n python3-%{mod_name}+zstd
Summary: Metapackage for python3-kafka: zstd extras
Requires: python(abi) = %{python3_version}
Requires: python3-kafka = %{version}-%{release}
Requires: python%{python3_version}dist(zstandard)
Provides: python-kafka+zstd = %{version}-%{release}
Provides: python%{python3_version}-kafka+zstd = %{version}-%{release}
Provides: python%{python3_version}dist(kafka-python[zstd]) = %{version}
Provides: python3dist(kafka-python[zstd]) = %{version}

%description -n python3-kafka+zstd
This is a metapackage bringing in zstd extras requires for python3-kafka.  It makes sure the
dependencies are installed.

%package -n python3-%{mod_name}
Summary:          Pure Python client for Apache Kafka

%description -n python3-%{mod_name}
This module provides low-level protocol support for Apache Kafka as well as high-level consumer and
producer classes. Request batching is supported by the protocol as well as broker-aware request
routing. Gzip and Snappy compression is also supported for message sets.

%package -n python3-kafka+lz4
Summary: Metapackage for python3-kafka: lz4 extras
Requires: python3-kafka = %{version}-%{release}

%description -n python3-kafka+lz4
This is a metapackage bringing in lz4 extras requires for python3-kafka.  It makes sure the dependencies are installed.

%package -n python3-kafka+snappy
Summary: Metapackage for python3-kafka: snappy extras
Requires: python3-kafka = %{version}-%{release}

%description -n python3-kafka+snappy
This is a metapackage bringing in snappy extras requires for python3-kafka. It makes sure the dependencies are installed.

%prep
%autosetup -p0 -n %{project_name}-%{version}
install -m 644 %{SOURCE1} %{_builddir}/%{project_name}-%{version}/LICENSE_doc

%generate_buildrequires
%pyproject_buildrequires -r

%build
%pyproject_wheel
%make_build doc
rm -rf docs/_build/html/.buildinfo

%install
%pyproject_install
install -pm 755 kafka/record/_crc32c.py %{buildroot}/%{python3_sitelib}/%{mod_name}/record/_crc32c.py
%py3_shebang_fix %{buildroot}/%{python3_sitelib}/%{mod_name}/record/_crc32c.py
%pyproject_save_files %{mod_name}

%check
%pytest --ignore="test/test_consumer_integration.py" --ignore="test/record/test_util.py" test

%files -n python3-%{mod_name} -f %{pyproject_files}
%license LICENSE LICENSE_doc
%doc AUTHORS.md CHANGES.md README.rst
%doc docs/_build/html

%files -n python3-kafka+zstd

%files -n python3-kafka+lz4

%files -n python3-kafka+snappy


%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.0.2-6
- Rebuilt for loongarch release

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.0.2-5
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.0.2-4
- Rebuilt for OpenCloudOS Stream 23.09

* Thu Aug 31 2023 wynnfeng <wynnfeng@tencent.com> - 2.0.2-3
- fix test assert error

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.0.2-2
- Rebuilt for OpenCloudOS Stream 23.05

* Wed Apr 26 2023 Shuo Wang <abushwang@tencent.com> - 2.0.2-1
- initial build
